@@ -1,21 +1,8 @@
 /*
-  Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
-  Copyright (c) 2009-2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+  SPDX-FileCopyrightText: 2009-2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "attendeeline.h"
@@ -40,7 +27,6 @@ typedef QPair<QString, QIcon> TextIconPair;
 AttendeeComboBox::AttendeeComboBox(QWidget *parent)
     : QToolButton(parent)
     , mMenu(new QMenu(this))
-    , mCurrentIndex(-1)
 {
     setPopupMode(QToolButton::InstantPopup);
     setToolButtonStyle(Qt::ToolButtonIconOnly);
@@ -123,7 +109,7 @@ void AttendeeLineEdit::keyPressEvent(QKeyEvent *ev)
     if ((ev->key() == Qt::Key_Enter || ev->key() == Qt::Key_Return)
         && !completionBox()->isVisible()) {
         Q_EMIT downPressed();
-        KPIM::AddresseeLineEdit::keyPressEvent(ev);
+        PimCommon::AddresseeLineEdit::keyPressEvent(ev);
     } else if (ev->key() == Qt::Key_Backspace && text().isEmpty()) {
         ev->accept();
         Q_EMIT deleteMe();
@@ -140,7 +126,7 @@ void AttendeeLineEdit::keyPressEvent(QKeyEvent *ev)
     } else if (ev->key() == Qt::Key_Up) {
         Q_EMIT upPressed();
     } else {
-        KPIM::AddresseeLineEdit::keyPressEvent(ev);
+        PimCommon::AddresseeLineEdit::keyPressEvent(ev);
     }
 }
 
