@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "combinedincidenceeditor.h"
@@ -28,7 +15,6 @@ using namespace IncidenceEditorNG;
 
 CombinedIncidenceEditor::CombinedIncidenceEditor(QWidget *parent)
     : IncidenceEditor(parent)
-    , mDirtyEditorCount(0)
 {
 }
 
@@ -88,7 +74,7 @@ void CombinedIncidenceEditor::handleDirtyStatusChange(bool isDirty)
     }
 }
 
-void CombinedIncidenceEditor::load(const KCalCore::Incidence::Ptr &incidence)
+void CombinedIncidenceEditor::load(const KCalendarCore::Incidence::Ptr &incidence)
 {
     mLoadedIncidence = incidence;
     for (IncidenceEditor *editor : qAsConst(mCombinedEditors)) {
@@ -140,7 +126,7 @@ void CombinedIncidenceEditor::load(const Akonadi::Item &item)
     Q_EMIT dirtyStatusChanged(false);
 }
 
-void CombinedIncidenceEditor::save(const KCalCore::Incidence::Ptr &incidence)
+void CombinedIncidenceEditor::save(const KCalendarCore::Incidence::Ptr &incidence)
 {
     for (IncidenceEditor *editor : qAsConst(mCombinedEditors)) {
         editor->save(incidence);
