@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "incidenceattachment.h"
@@ -23,7 +10,7 @@
 #include "attachmenticonview.h"
 #include "ui_dialogdesktop.h"
 
-#include <KdepimDBusInterfaces/UriHandler>
+#include <CalendarSupport/UriHandler>
 
 #include <KContacts/VCardDrag>
 
@@ -35,7 +22,8 @@
 #include <QMenu>
 #include <KMessageBox>
 #include <KProtocolManager>
-#include <KRun>
+#include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
 #include <KIO/Job>
 #include <KIO/StoredTransferJob>
 #include <KJobWidgets>
@@ -90,7 +78,7 @@ void IncidenceAttachment::save(const KCalendarCore::Incidence::Ptr &incidence)
 
     for (int itemIndex = 0; itemIndex < mAttachmentView->count(); ++itemIndex) {
         QListWidgetItem *item = mAttachmentView->item(itemIndex);
-        AttachmentIconItem *attitem = dynamic_cast<AttachmentIconItem *>(item);
+        auto *attitem = dynamic_cast<AttachmentIconItem *>(item);
         Q_ASSERT(item);
         incidence->addAttachment(attitem->attachment());
     }
@@ -167,7 +155,7 @@ void IncidenceAttachment::copyToClipboard()
 void IncidenceAttachment::openURL(const QUrl &url)
 {
     QString uri = url.url();
-    UriHandler::process(uri);
+    CalendarSupport::UriHandler::process(uri);
 }
 
 void IncidenceAttachment::pasteFromClipboard()
@@ -185,7 +173,7 @@ void IncidenceAttachment::removeSelectedAttachments()
     for (int itemIndex = 0; itemIndex < mAttachmentView->count(); ++itemIndex) {
         QListWidgetItem *it = mAttachmentView->item(itemIndex);
         if (it->isSelected()) {
-            AttachmentIconItem *attitem = static_cast<AttachmentIconItem *>(it);
+            auto *attitem = static_cast<AttachmentIconItem *>(it);
             if (attitem) {
                 const KCalendarCore::Attachment att = attitem->attachment();
                 labels << att.label();
@@ -233,7 +221,7 @@ void IncidenceAttachment::saveAttachment(QListWidgetItem *item)
     Q_ASSERT(item);
     Q_ASSERT(dynamic_cast<AttachmentIconItem *>(item));
 
-    AttachmentIconItem *attitem = static_cast<AttachmentIconItem *>(item);
+    auto *attitem = static_cast<AttachmentIconItem *>(item);
     if (attitem->attachment().isEmpty()) {
         return;
     }
@@ -275,7 +263,7 @@ void IncidenceAttachment::showAttachment(QListWidgetItem *item)
 {
     Q_ASSERT(item);
     Q_ASSERT(dynamic_cast<AttachmentIconItem *>(item));
-    AttachmentIconItem *attitem = static_cast<AttachmentIconItem *>(item);
+    auto *attitem = static_cast<AttachmentIconItem *>(item);
     if (attitem->attachment().isEmpty()) {
         return;
     }
@@ -284,10 +272,11 @@ void IncidenceAttachment::showAttachment(QListWidgetItem *item)
     if (att.isUri()) {
         openURL(QUrl(att.uri()));
     } else {
-        KRun::RunFlags flags;
-        flags |= KRun::DeleteTemporaryFiles;
-        flags |= KRun::RunExecutables;
-        KRun::runUrl(attitem->tempFileForAttachment(), att.mimeType(), nullptr, flags);
+        KIO::OpenUrlJob *job = new KIO::OpenUrlJob(attitem->tempFileForAttachment(), att.mimeType());
+        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, mAttachmentView));
+        job->setDeleteTemporaryFile(true);
+        job->setRunExecutables(true);
+        job->start();
     }
 }
 
@@ -340,7 +329,7 @@ void IncidenceAttachment::editSelectedAttachments()
         if (item->isSelected()) {
             Q_ASSERT(dynamic_cast<AttachmentIconItem *>(item));
 
-            AttachmentIconItem *attitem = static_cast<AttachmentIconItem *>(item);
+            auto *attitem = static_cast<AttachmentIconItem *>(item);
             if (attitem->attachment().isEmpty()) {
                 return;
             }
@@ -562,7 +551,7 @@ void IncidenceAttachment::setupAttachmentIconView()
     connect(mAttachmentView, &AttachmentIconView::customContextMenuRequested, this,
             &IncidenceAttachment::showContextMenu);
 
-    QGridLayout *layout = new QGridLayout(mUi->mAttachmentViewPlaceHolder);
+    auto *layout = new QGridLayout(mUi->mAttachmentViewPlaceHolder);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(mAttachmentView);
 }
