@@ -1,20 +1,8 @@
 /*
-  Copyright (C) 2010  Bertjan Broeksema <broeksema@kde.org>
-  Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "korganizereditorconfig.h"
@@ -25,9 +13,9 @@
 #include <akonadi/calendar/calendarsettings.h>
 #include <Item>
 
-#include <KCalCore/Event>
-#include <KCalCore/Todo>
-#include <KCalCore/Journal>
+#include <KCalendarCore/Event>
+#include <KCalendarCore/Todo>
+#include <KCalendarCore/Journal>
 
 #include <QApplication>
 #include <QCommandLineParser>
@@ -46,12 +34,12 @@ int main(int argc, char **argv)
     QCommandLineParser parser;
     parser.addHelpOption();
     parser.addVersionOption();
-    parser.addOption(QCommandLineOption(QStringLiteral("new-event"), i18n("Creates a new event")));
-    parser.addOption(QCommandLineOption(QStringLiteral("new-todo"), i18n("Creates a new todo")));
-    parser.addOption(QCommandLineOption(QStringLiteral("new-journal"), i18n(
+    parser.addOption(QCommandLineOption(QStringLiteral("new-event"), QStringLiteral("Creates a new event")));
+    parser.addOption(QCommandLineOption(QStringLiteral("new-todo"), QStringLiteral("Creates a new todo")));
+    parser.addOption(QCommandLineOption(QStringLiteral("new-journal"), QStringLiteral(
                                             "Creates a new journal")));
     parser.addOption(QCommandLineOption(QStringLiteral("item"),
-                                        i18n(
+                                        QStringLiteral(
                                             "Loads an existing item, or returns without doing anything "
                                             "when the item is not an event or todo."),
                                         QStringLiteral("id")));
@@ -75,19 +63,19 @@ int main(int argc, char **argv)
 
     if (parser.isSet(QStringLiteral("new-event"))) {
         std::cout << "Creating new event..." << std::endl;
-        KCalCore::Event::Ptr event(new KCalCore::Event);
+        KCalendarCore::Event::Ptr event(new KCalendarCore::Event);
         defaults.setDefaults(event);
-        item.setPayload<KCalCore::Event::Ptr>(event);
+        item.setPayload<KCalendarCore::Event::Ptr>(event);
     } else if (parser.isSet(QStringLiteral("new-todo"))) {
         std::cout << "Creating new todo..." << std::endl;
-        KCalCore::Todo::Ptr todo(new KCalCore::Todo);
+        KCalendarCore::Todo::Ptr todo(new KCalendarCore::Todo);
         defaults.setDefaults(todo);
-        item.setPayload<KCalCore::Todo::Ptr>(todo);
+        item.setPayload<KCalendarCore::Todo::Ptr>(todo);
     } else if (parser.isSet(QStringLiteral("new-journal"))) {
         std::cout << "Creating new journal..." << std::endl;
-        KCalCore::Journal::Ptr journal(new KCalCore::Journal);
+        KCalendarCore::Journal::Ptr journal(new KCalendarCore::Journal);
         defaults.setDefaults(journal);
-        item.setPayload<KCalCore::Journal::Ptr>(journal);
+        item.setPayload<KCalendarCore::Journal::Ptr>(journal);
     } else if (parser.isSet(QStringLiteral("item"))) {
         bool ok = false;
         qint64 id = parser.value(QStringLiteral("item")).toLongLong(&ok);
@@ -106,7 +94,7 @@ int main(int argc, char **argv)
 
     EditorConfig::setEditorConfig(new KOrganizerEditorConfig);
 
-    IncidenceDialog *dialog = new IncidenceDialog();
+    auto *dialog = new IncidenceDialog();
 
     Akonadi::Collection collection(CalendarSupport::KCalPrefs::instance()->defaultCalendarId());
 
